@@ -21,20 +21,20 @@ import warnings
 #from threading import Lock
 
 import tomlkit
-from PySide2 import QtCore, QtGui, QtWidgets #pylint: disable=import-error
-from PySide2.QtWidgets import QMessageBox    #pylint: disable=no-name-in-module
-from PySide2.QtUiTools import loadUiType     #pylint: disable=no-name-in-module
-from PySide2.QtCore import Signal            #pylint: disable=no-name-in-module
-from PySide2.QtCore import QRectF            #pylint: disable=no-name-in-module
+from PySide6 import QtCore, QtGui, QtWidgets
+from PySide6.QtWidgets import QMessageBox
+from PySide6.QtUiTools import loadUiType
+from PySide6.QtCore import Signal
+from PySide6.QtCore import QRectF
 import numpy as np
 
-import pyqtgraph as pg                       #pylint: disable=import-error 
-import configuration as config               #pylint: disable=import-error 
-import hardware as hw                        #pylint: disable=import-error 
-import datastorage as ds                     #pylint: disable=import-error 
-from qtwidgets import FlowLayout             #pylint: disable=import-error 
+import pyqtgraph as pg
+import configuration as config
+import hardware as hw
+import datastorage as ds
+from qtwidgets import FlowLayout
 
-from utils import si_unit_factor  #pylint: disable=import-error
+from utils import si_unit_factor
 
 #: Default settings to place in configuration file if not existing already.
 _default_config = \
@@ -72,14 +72,15 @@ highlight = [192, 192, 192, 255]
 """
 
 class DataPanel(QtWidgets.QWidget, loadUiType(__file__.split(".py")[0] + ".ui")[0]):
-
-    acquisition_completed = Signal(Exception)
-
     """
     UI panel to facilitate the collection and viewing of data.
 
     :param parent: Parent of the QWidget.
     """
+
+    #: Signal to respond to the end of acquisition.
+    acquisition_completed = Signal(Exception)
+    
     def __init__(self, parent=None):
         super().__init__(parent)
         self.setupUi(self)
