@@ -30,15 +30,15 @@ import logging
 import time
 
 import numpy as np
-import zarr                                                 #pylint: disable=import-error
+import zarr
 from scipy.stats import norm
 from scipy.ndimage import median_filter
-from PySide2.QtWidgets import QFileDialog, QMessageBox      #pylint: disable=no-name-in-module
-from PySide2 import QtCore                                  #pylint: disable=import-error
-from PySide2.QtCore import Signal                           #pylint: disable=no-name-in-module
+from PySide6.QtWidgets import QFileDialog, QMessageBox
+from PySide6 import QtCore
+from PySide6.QtCore import Signal
 
-import configuration as config                              #pylint: disable=import-error 
-from ufsfile import UFSData                                 #pylint: disable=import-error 
+import configuration as config
+from ufsfile import UFSData
 from utils import clean_filename, now_string
 
 # Logger for this module. 
@@ -569,7 +569,7 @@ def export_raw_average(parent=None, initial_dir=None):
         if "sample" in t["raw"].attrs:
             samplename = t["raw"].attrs["sample"]
         else:
-            samplename = data["raw"].attrs["sample"]
+            samplename = d["raw"].attrs["sample"]
         if samplename: samplename = "-" + samplename
     except:
         samplename = ""
@@ -577,7 +577,7 @@ def export_raw_average(parent=None, initial_dir=None):
         if "pump" in t["raw"].attrs:
             pumpname = t["raw"].attrs["pump"]
         else:
-            pumpname = data["raw"].attrs["pump"]
+            pumpname = d["raw"].attrs["pump"]
         if pumpname: pumpname = "-" + pumpname
     except:
         pumpname = ""
