@@ -17,8 +17,8 @@
 
 import logging
 
-from PySide2 import QtCore, QtGui, QtWidgets  #pylint: disable=import-error
-from PySide2.QtUiTools import loadUiType      #pylint: disable=no-name-in-module
+from PySide6 import QtCore, QtGui, QtWidgets
+from PySide6.QtUiTools import loadUiType
 
 class LogPanel(QtWidgets.QFrame, loadUiType(__file__.split(".py")[0] + ".ui")[0]):
 
