@@ -21,10 +21,10 @@ import warnings
 import numpy as np
 import zarr
 
-import configuration as config  #pylint: disable=import-error
-import hardware as hw           #pylint: disable=import-error
-import datastorage as ds        #pylint: disable=import-error
-from utils import AcquisitionError, AcquisitionAbortedWarning, no_infs, si_unit_factor, status_message, now_string  #pylint: disable=import-error
+import configuration as config
+import hardware as hw
+import datastorage as ds
+from utils import AcquisitionError, AcquisitionAbortedWarning, no_infs, si_unit_factor, status_message, now_string
 
 from . import Acquisition
 
