@@ -22,7 +22,7 @@ import sys
 
 import tomlkit
 
-import configuration as config            #pylint: disable=import-error
+import configuration as config
 from .scopepanel import ScopePanel
 
 
@@ -41,7 +41,7 @@ reference_deltaA = ""
 config.add_defaults(tomlkit.parse(_default_config))
 
 # Bypass this code block if module was imported by sphinx documentation generation utility
-if not "sphinx-build" in os.path.basename(sys.argv[0]):
+if not "sphinx" in sys.argv[0]:
     
     # Add the scope panel tab to the main window
     config.mainwindow.scopePanel = ScopePanel()
