@@ -21,17 +21,17 @@ from time import sleep, monotonic, strftime, localtime
 from threading import Thread, Event
 
 
-from PySide2 import QtCore, QtWidgets      #pylint: disable=import-error
-from PySide2.QtWidgets import QFileDialog, QMessageBox      #pylint: disable=no-name-in-module
-from PySide2.QtUiTools import loadUiType   #pylint: disable=no-name-in-module
-from PySide2.QtCore import Signal          #pylint: disable=no-name-in-module
+from PySide6 import QtCore, QtWidgets
+from PySide6.QtWidgets import QFileDialog, QMessageBox
+from PySide6.QtUiTools import loadUiType
+from PySide6.QtCore import Signal
 import numpy as np
 
-import pyqtgraph as pg                     #pylint: disable=import-error 
-import configuration as config             #pylint: disable=import-error
-import hardware as hw                      #pylint: disable=import-error
-import datastorage as ds                   #pylint: disable=import-error
-from utils import AcquisitionError, AcquisitionAbortedWarning, no_infs, status_message, si_unit_factor  #pylint: disable=import-error
+import pyqtgraph as pg
+import configuration as config
+import hardware as hw
+import datastorage as ds
+from utils import AcquisitionError, AcquisitionAbortedWarning, no_infs, status_message, si_unit_factor
 
 
 class ScopePanel(QtWidgets.QWidget, loadUiType(__file__.split(".py")[0] + ".ui")[0]):
